% CellROI is a tool to extract cell coordinates from the reconstructed
% scintillation count data (ScintData.mat). 
%
% Version 1.01
% *Addressed incorrect scaling for reconstructed images with bin size smaller than 4.
%
% Procedure:
% 1. Type GetCells(value) in the command window. The value in the
%  parenthesis will determine the size of the circular region of interest.
%  If nothing is entered the default value will be 15 px.
% 2. Navigate through the folders to open the 'ScintData.mat'. 
% 3. First pair of figures will open to select radioactive cells.
% 4. Use 'Alt+Tab' to toggle between the brightfield image and the 
%  reconstructed scintillation image.
% 5. Select cells that can be clearly distinguished.
%   i. Left mouse click - select cells (white circle)
%   ii. Right mouse click - cancel current selection (red circle)
%   iii. Middle mouse click - Finish collecting data
% 6. Second pair of figure will open to select radioactive background.
% 7. Use 'Alt+Tab' to toggle between the brightfield image and the 
%  reconstructed scintillation image.
% 8. Select background ROIs where no cells and radioactivity are present
%  until the figure closes (same number of data points as the number of
%  radioactive cells selected).
% 9. The program will output 'PlotCoordinates' which has the information on
%  the number of decay counts detected per cell, number of decay counts
%  detected in background, and the corrresponding coordinates.

function [A, Ab, X, Y, Xb, Yb] = CellROI(R)

if nargin<1
    R=15;
else
end

[filename, pathname]= uigetfile({'*.mat'},'Multiselect','off');

if pathname==0;
    display('Please select file');
else

    load([pathname,filename]);

    a=Img_BF;
    b=Img_DecayRawSmoothed;
    c=Data_DecayRaw;
    
    bin=Par_Binning;

    h1=msgbox('Please select areas with activity that contain single cells');
    child = get(h1,'Children');
    delete(child(2))

    pause(1.5);
    delete(h1);

    [X,Y] = ROIm(imresize(imfilter(b,fspecial('Gaussian',21,1.5)),1,'nearest'), a, 200, 0, max(max(b)), 0.5*mean(mean(a)), max(max(a)), jet, gray, R);
    A = ROIc(c,X/bin,Y/bin,R/bin);

    ImgLim=size(A,1);
    
    h2=msgbox('Please select blank areas with no activity');
    child = get(h2,'Children');
    delete(child(2))

    pause(1.5); 
    delete(h2);

    [Xb,Yb] = ROIm(imresize(imfilter(b,fspecial('Gaussian',21,1.5)),1,'nearest'), a, ImgLim, 0, max(max(b)), 0.5*mean(mean(a)), max(max(a)), jet, gray, R);
    Ab = ROIc(c,Xb/bin,Yb/bin,R/bin); % background
    
    CellSum=A;
    BgdSum=Ab;
    X_Cell=X;
    Y_Cell=Y;
    X_Bgd=Xb;
    Y_Bgd=Yb;

    save PlotCoordinates.mat CellSum BgdSum X_Cell Y_Cell X_Bgd Y_Bgd
    close all
end


function [T] = ROIc( I, X, Y, R )
% evaluate sum intensity inside circular ROIs on one image
% T = ROIc( I, X, Y, R )
% I: image
% X,Y: ROI coordinate produced using ROIm
% R: ROI radius (in pixels)

[N] = size(X,1);

T = zeros(N,1);

vx = size(I,1);

for i = 1:N

    C = roicirc(X(i),Y(i),R,vx);

    T(i) = sum( I(C>0) );

end


function [X,Y] = ROIm(I1, I2, Nmax, mi1, ma1, mi2, ma2, cm1, cm2, R)

% create ROIs for single image
% [X,Y] = ROIm(I1, I2, Nmax, mi1, ma1, mi2, ma2, cm1, cm2, R)
% I1, I2: dual modality images
% Nmax: maximum number of ROIs (e.g. 200)
% mi1, mi2, ma1, ma2: min max for both images
% cm1, cm2: colormaps (e.g. jet, gray, etc.)
% radius of ROI in pixels (e.g. 10)

close all;

figure(1);
imagesc(I1,[mi1 ma1]);axis image;colormap(cm1);

figure(2);
imagesc(I2,[mi2 ma2]);axis image;colormap(cm2);
drawnow;

Xi = zeros(Nmax,1);
Yi = zeros(Nmax,1);

b = 1;
i = 1;

while (b~=2 && i<=Nmax)

[x,y,b] = ginput(1);

if (b==1)

figure(1);
rectangle('Position',[x-R,y-R,2*R,2*R],'Curvature',[1 1],'EdgeColor',[1 1 1]);
figure(2);
rectangle('Position',[x-R,y-R,2*R,2*R],'Curvature',[1 1],'EdgeColor',[1 1 1]);

Xi(i) = x;
Yi(i) = y;

i = i + 1;

elseif (b==3)
i = i-1;
figure(1);
rectangle('Position',[Xi(i)-R,Yi(i)-R,2*R,2*R],'Curvature',[1 1],'EdgeColor',[1 0 0]);
figure(2);
rectangle('Position',[Xi(i)-R,Yi(i)-R,2*R,2*R],'Curvature',[1 1],'EdgeColor',[1 0 0]);
end

end

X = Xi(1:i-1);
Y = Yi(1:i-1);


function R = roicirc(x,y,r,v)
% R = roicirc(x,y,r,v)
% x,y: center
% r: radius
% v: output image size

[X,Y] = meshgrid(1:v,1:v);

R = (X-x).^2 + (Y-y).^2 < r^2;
